@@ -521,6 +521,8 @@ def write(t, c, size=16, style=None, family=None):
 
 @check_pen
 def tetris_cz(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -534,10 +536,13 @@ def tetris_cz(t, x=None, y=None, size=50):
     move(t, x + 50, y)
     square(t, size)
     move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_rz(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -551,10 +556,13 @@ def tetris_rz(t, x=None, y=None, size=50):
     move(t, x - 50, y)
     square(t, size)
     move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_or(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -568,10 +576,13 @@ def tetris_or(t, x=None, y=None, size=50):
     move(t, x - 50, y)
     square(t, size)
     move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_br(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -585,10 +596,13 @@ def tetris_br(t, x=None, y=None, size=50):
     move(t, x + 50, y)
     square(t, size)
     move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_h(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -601,11 +615,14 @@ def tetris_h(t, x=None, y=None, size=50):
     square(t, size)
     move(t, x, y - 100)
     square(t, size)
-    move(t, x, y - 100)
+    move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_t(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -619,10 +636,13 @@ def tetris_t(t, x=None, y=None, size=50):
     move(t, x, y)
     square(t, size)
     move(t, x, y)
+    t.seth(t_degree)
 
 
 @check_pen
 def tetris_s(t, x=None, y=None, size=50):
+    t_degree = t.heading()
+    t.seth(0)
     if x is None:
         x = t.xcor()
     if y is None:
@@ -635,4 +655,5 @@ def tetris_s(t, x=None, y=None, size=50):
     square(t, size)
     move(t, x, y)
     square(t, size)
-    move(t, x, y)
\ No newline at end of file
+    move(t, x, y)
+    t.seth(t_degree)
\ No newline at end of file
